/*	picture.h
 *
 */

#ifndef _INCLUDE_PICTURE_H_
#define _INCLUDE_PICTURE_H_

#include "motion.h"

void put_picture_fd (struct context *, FILE *, char *, int);
void put_picture (struct context *, char *, char *, int );

#endif /* _INCLUDE_PICTURE_H_ */
